# Tests for smalldi

This module contains tests for a smalldi library with the use of pytest

## Test structure
- `test_provide.py` - Tests for class `Provide`
- `test_injector.py` - Тests for class `Injector`
- `test_wrappers.py` - Tests for wrappers (currently only `staticclass`)
- `test_integration.py` - Library-level tests
